function spm_separation()
% plots Figure 5 of paper "RECENT ADVANCES IN TIME-FREQUENCY REASSIGNMENT AND
%   SYNCHROSQUEEZING", by Meignen et al.

% Read bat signal
[s fs]=wavread('mdaub00001_7.wav');s = s(2501:4548);

% Zero padding to be power of 2
s = comp(s);
% normalize
s = s/norm(s)*sqrt(length(s));
%plot(s);return;

% Constants and parameters
N = length(s);
frecv=1:1:N/4;
timev=1:1:N;
t = 1/fs*(0:N-1);
lambda = 0.01;
gamma = 0.01;


%% SST 2 modes
sigma = 0.08;
[Vs Ts Rs] = sst(s,gamma,sigma,frecv,timev);
ha = subplot(2,4,1);
tfplot(Ts,t(timev),(frecv-1)*fs/N/2/pi,ha);
set(ha,'ylim',[0 25000],'xtick',[],'ytick',[]);

% Ridge extraction
[C, Es] = brevridge_mult(Ts, frecv, 2, lambda, 5);

% IMF plot
srec1 = zeros(size(s));
srec2 = zeros(size(s));
Delta = 5;
for b=1:length(timev)
	srec1(b) = sum(Ts(max(1,C(1,b)-Delta):min(length(frecv),C(1,b)+Delta),b));
    srec2(b) = sum(Ts(max(1,C(2,b)-Delta):min(length(frecv),C(2,b)+Delta),b));
end
srec1 = 2*real(srec1);
srec2 = 2*real(srec2);
subplot(2,4,[3 4]);
plot(t,srec1,'b',t,srec2,'r');
set(gca,'xtick',[]);xlabel('b');


%% HHT
fs = 1/fs;

imf = emd(s);
for k = 1:length(imf)
   b(k) = sum(imf{k}.*imf{k});
   th   = angle(hilbert(imf{k}));
   d{k} = diff(th)/fs/(2*pi)^2;
end
[u,v] = sort(-b);
b     = 1-b/max(b);

% Set time-frequency plots.
ha=subplot(2,4,5);hold(ha);
for k = v(1:2)
   plot(t(1:end-1),d{k},'k.','Color',b([k k k]),'MarkerSize',3,'Parent',ha);
end
set(ha,'ylim',[0 25000],'xtick',[],'ytick',[]);xlabel('b');ylabel('\omega');

% IMF plot
subplot(2,4,[7 8]);
plot(t,imf{1});
xlabel('b');

explot();

end

